==> tikiwiki-10.2.txz: usr/local/www/tikiwiki-10.2/lang/fr/language.js <==
/* 
 * Javascript translation definition
 * Example to help translation of some English strings in some js files
 * 
 * $Id: language.js 30343 2010-10-27 12:50:51Z xavidp $
 */

lang = {
	"Default" : "Défaut",
	"Very Secure" : "Très sécurisé",
	"Secure" : "Sécurisé",
	"Very Strong" : "Très fort",
	"Strong" : "Fort",
	"Average" : "Moyenne",
	"Weak" : "Faible",
	"Very Weak" : "Très faible",
	"Strength" : "Robustesse",
	"Valid User Name" : "Nom utilisateur valide",
	"Passwords match" : "Les mots de passe concordent",
	"Valid Email" : "Adresse courriel valide",
	"Close" : "Fermer",
	"Submit" : "Envoyer",
	"Insert" : "Insérer",
	"Replace" : "Remplacer",
	"Match" : "Correspondent",
	"Do not match" : "Ne correspondent pas",
	"Advanced options" : "Options avancées",
	"Pick a file." : "Choisir un fichier.",
	"Add Field" : "Ajouter un champ",
	"Edit Field" : "Modifier le champ",
	"Removing the field will result in data loss. Are you sure?" : "La suppression du champ entrainera la perte des données. Êtes-vous sûr(e) ?",
	"Save" : "Enregistrer",
	"Cancel" : "Annuler",
	"Delete" : "Supprimer",	
	"Unassign module" : "Supprimer le module",
	"Edit module" : "Modifier le module",
	"Edit module:" : "Modifier le module :",
	"Favorite" : "Favoris",
	"What address are you looking for?" : "Quelle adresse recherchez-vous ?",
	"Filter:" : "Filtre :",
	"Please enter a page name" : "Veuillez entrer un nom de page",
	"Are you sure you want to unassign this module?" : "Êtes-vous sûr(e) de vouloir désattribuer ce module ?",
	"StreetView is not available at this specific point on the map. Zoom in as needed and make sure to click on a blue line." : "La fonction StreetView n'est pas disponible à cet endroit précis sur la carte. Approchez votre zoom au besoin et assurez-vous de cliquer sur une ligne bleue."

	// remember the IE does not support ending comma on last item
};

==> tikiwiki-15.0.txz: usr/local/www/tikiwiki-15.0/lang/fr/language.js <==
/* 
 * Javascript translation definition
 * Example to help translation of some English strings in some js files
 * 
 * $Id: language.js 30343 2010-10-27 12:50:51Z xavidp $
 */

lang = {
	"Default" : "Défaut",
	"Very Secure" : "Très sécurisé",
	"Secure" : "Sécurisé",
	"Very Strong" : "Très fort",
	"Strong" : "Fort",
	"Average" : "Moyenne",
	"Weak" : "Faible",
	"Very Weak" : "Très faible",
	"Strength" : "Robustesse",
	"Valid User Name" : "Nom utilisateur valide",
	"Passwords match" : "Les mots de passe concordent",
	"Valid Email" : "Adresse courriel valide",
	"Close" : "Fermer",
	"Submit" : "Envoyer",
	"Insert" : "Insérer",
	"Replace" : "Remplacer",
	"Match" : "Correspondent",
	"Do not match" : "Ne correspondent pas",
	"Advanced options" : "Options avancées",
	"Pick a file." : "Choisir un fichier.",
	"Add Field" : "Ajouter un champ",
	"Edit Field" : "Modifier le champ",
	"Removing the field will result in data loss. Are you sure?" : "La suppression du champ entraînera la perte des données. Êtes-vous sûr(e) ?",
	"Save" : "Enregistrer",
	"Cancel" : "Annuler",
	"Delete" : "Supprimer",	
	"Unassign module" : "Supprimer le module",
	"Edit module" : "Modifier le module",
	"Edit module:" : "Modifier le module :",
	"Favorite" : "Favoris",
	"What address are you looking for?" : "Quelle adresse recherchez-vous ?",
	"Filter:" : "Filtre :",
	"Please enter a page name" : "Veuillez entrer un nom de page",
	"Are you sure you want to unassign this module?" : "Êtes-vous sûr(e) de vouloir désattribuer ce module ?",
	"Search Location" : "Chercher une adresse",
	"To My Location" : "Localiser ma position",
	"StreetView is not available at this specific point on the map. Zoom in as needed and make sure to click on a blue line." : "La fonction StreetView n'est pas disponible à cet endroit précis sur la carte. Approchez votre zoom au besoin et assurez-vous de cliquer sur une ligne bleue.",
	"Browse Files" : "Parcourir la liste des fichiers",
	"Page only allowed once in a structure" : "Page autorisée une seule fois dans une structure",
	// remember the IE does not support ending comma on last item
	 "Bogus entry" : "bogus entry"
};
